@@ -1,5 +1,5 @@
 from datetime import datetime
-import json
+import json, os
 
 class printr:
     '''printr'''
@@ -19,9 +19,19 @@ class printr:
             current_time = current_time.strftime('%H:%M:%S:%f')
             message = f'{current_time}: {message}'
         if same_line:
-            print(' ' * 200, end='')
+            terminal_size = os.get_terminal_size()
+            max_characters = terminal_size.columns - 1
+            print(' ' * max_characters, end='') # Clear previous output
             print('\r', end='')
             print(message, end='')
             print('\r', end='')
         else:
-            print(message)
\ No newline at end of file
+            print(message)
+
+class current_time:
+    def __init__(self, *items, same_line=False):
+        printr(same_line=same_line, current_time=True)
+
+class same_line:
+    def __init__(self, *items, current_time=False):
+        printr(same_line=same_line, current_time=current_time,)
\ No newline at end of file
